# This installs a PostgreSQL-XC Datanode
define postgresqlxc::datanode (
  $node_name,
  $postgresql_tmpl	      = $postgresqlxc::params::datanode_postgresql_tmpl,
  $pg_hba_tmpl		      = $postgresqlxc::params::datanode_pg_hba_tmpl,
  $init_tmpl		      = $postgresqlxc::params::datanode_init_tmpl,
  $postgresql_params	      = {},
  $pg_hba_params	      = [],
  $init_params		      = {},
  $user			      = $postgresqlxc::params::user,
  $group		      = $postgresqlxc::params::group,
  $pg_dir		      = $postgresqlxc::params::pg_dir,
  $bin_dir		      = $postgresqlxc::params::bin_dir
) {
  # Need to do some validation here.

  $db_type	= 'datanode'
  $base_dir	= "${pg_dir}/${db_type}_${node_name}"
  $data_dir	= "$base_dir/data"
  $service_name	= "pgxc_${db_type}_${node_name}"

  include postgresqlxc::install

  postgresqlxc::server::layout{"${db_type}_${node_name}": 
    user	=> $user,
    group	=> $group,
    base_dir	=> $base_dir,
    data_dir	=> $data_dir
  }

  postgresqlxc::server::initdb{"${db_type}_${node_name}": 
    user	=> $user,
    group	=> $group,
    initdb_path	=> "${bin_dir}/initdb",
    data_dir	=> $data_dir,
    db_type	=> $db_type,
    node_name   => $node_name
  }

  $real_postgresql_params = merge(  
    $postgresqlxc::params::datanode_postgresql_params, 
    { 'pgxc_node_name' => $node_name }, 
    $postgresql_params
  )

  $real_init_params = merge(  
    $postgresqlxc::params::datanode_init_params, 
    $init_params
  )

  postgresqlxc::server::config{"${db_type}_${node_name}":
    user		      => $user,
    group		      => $group,
    base_dir		      => $base_dir,
    data_dir		      => $data_dir,
    bin_dir		      => $bin_dir,
    db_type		      => $db_type,
    node_name		      => $node_name,
    service_name	      => $service_name,
    postgresql_tmpl	      => $postgresql_tmpl,
    postgresql_params	      => $real_postgresql_params,
    pg_hba_tmpl		      => $pg_hba_tmpl,
    pg_hba_params	      => $pg_hba_params,
    default_pg_hba_params     => $postgresqlxc::params::datanode_pg_hba_params,
    init_tmpl		      => $init_tmpl,
    init_params		      => $real_init_params
  }

  postgresqlxc::server::service{ "${db_type}_${node_name}":
    user		      => $user,
    data_dir		      => $data_dir,
    service_name	      => $service_name
  }

  postgresqlxc::server::node{ "${db_type}_${node_name}":
    node_name	      => $node_name,
    postgresql_params => $real_postgresql_params
  }

  

  Class['postgresqlxc::install']			    -> Postgresqlxc::Server::Layout["${db_type}_${node_name}"]
  Postgresqlxc::Server::Layout["${db_type}_${node_name}"]   -> Postgresqlxc::Server::Initdb["${db_type}_${node_name}"]
  Postgresqlxc::Server::Initdb["${db_type}_${node_name}"]   -> Postgresqlxc::Server::Config["${db_type}_${node_name}"]
  Postgresqlxc::Server::Config["${db_type}_${node_name}"]   -> Postgresqlxc::Server::Service["${db_type}_${node_name}"]
  Postgresqlxc::Server::Service["${db_type}_${node_name}"]  -> Postgresqlxc::Server::Node["${db_type}_${node_name}"]

}
