# This installs a PostgreSQL-XC GTM Proxy
class postgresqlxc::gtm_proxy (
  $node_name,
  $gtm_host,
  $gtm_proxy_conf_tmpl	      = $postgresqlxc::params::gtm_proxy_conf_tmpl,
  $gtm_proxy_conf_params      = {},
  $init_tmpl		      = $postgresqlxc::params::gtm_proxy_init_tmpl,
  $init_params		      = {},
  $user			      = $postgresqlxc::params::user,
  $group		      = $postgresqlxc::params::group,
  $pg_dir		      = $postgresqlxc::params::pg_dir,
  $bin_dir		      = $postgresqlxc::params::bin_dir,
  $service_ensure	      = $postgresqlxc::params::service_ensure,
  $service_enabled	      = $postgresqlxc::params::service_enabled
) inherits postgresqlxc::params {

  # Need to do some validation here.

  $db_type	= 'gtm_proxy'
  $base_dir	= "$pg_dir/$db_type"
  $data_dir	= "$base_dir/data"
  $service_name	= "pgxc_${db_type}"
  $quote_params	= $postgresqlxc::params::quote_params

  include postgresqlxc::install

  File {
    ensure => $ensure,
    owner  => $user,
    group  => $group,
  }

  postgresqlxc::gtm::initgtm{ "$db_type": 
    user	=> $user,
    group	=> $group,
    bin_dir	=> $bin_dir,
    pg_dir	=> $pg_dir,
    db_type	=> $db_type,
    data_dir	=> $data_dir
  }

  $real_conf_params = merge(  
    $postgresqlxc::params::gtm_proxy_conf_params, 
    { 'nodename' => $node_name, 'gtm_host' => $gtm_host  }, 
    $gtm_proxy_conf_params
  )


  file {"${data_dir}/gtm_proxy.conf":
    content => template($gtm_proxy_conf_tmpl)
  }

  file {"/etc/init.d/${service_name}":
    content => template($init_tmpl),
    owner   => 0,
    group   => 0,
    mode    => '0755'
  }

  service { $service_name:
    ensure    => true,
    name      => "pgxc_${db_type}",
    enable    => true,
    hasstatus => true,
    subscribe => File["${data_dir}/gtm_proxy.conf"]
  }

  Class['postgresqlxc::install']	  -> Postgresqlxc::Gtm::Initgtm["$db_type"]
  Postgresqlxc::Gtm::Initgtm["$db_type"]  -> File["${data_dir}/gtm_proxy.conf"]
  File["${data_dir}/gtm_proxy.conf"]	  -> File["/etc/init.d/${service_name}"]	  
  File["/etc/init.d/${service_name}"]	  -> Service[$service_name]

}
