# PRIVATE CLASS: do not use directly
class postgresqlxc::params {
  # ---------------------------------------------------------------------------
  # General
  # ---------------------------------------------------------------------------
  $user			= 'pgxc'
  $group		= 'pgxc'
  $version		= '1.1'
  $user_is_virtualized	= true
  $pgxc_group_params	= { 
    'ensure' => 'present',
    'gid'    => '225' 
  }
  $pgxc_user_params	= { 
    'ensure'	     => 'present',
    'comment'        => 'PostgresXC',
    'uid'            => 225,
    'gid'            => 225,
    'home'           => '/var/lib/pgsql',
    'managehome'     => 'true',
    'shell'          => '/bin/bash'
  }

  $pg_dir            = '/da01/pgxc'
  $bin_dir           = "/usr/pgxc-${version}/bin"
  $client_package    = ['postgres-xc']
  $server_package    = ['postgres-xc', 'postgres-xc-server', 'postgres-xc-libs', 'postgres-xc-gtm']

  $quote_params = {
    'listen_addresses'		 => 1,
    'log_destination'		 => 1,
    'log_filename'		 => 1,
    'log_file'			 => 1,
    'log_timezone'		 => 1,
    'datestyle'			 => 1,
    'timezone'			 => 1,
    'lc_messages'		 => 1,
    'lc_monetary'		 => 1,
    'lc_numeric'		 => 1,
    'lc_time'			 => 1,
    'default_text_search_config' => 1,
    'gtm_host'			 => 1,
    'nodename'			 => 1,
    'pgxc_node_name'		 => 1,
  }

  # ---------------------------------------------------------------------------
  # Coordinator	
  # ---------------------------------------------------------------------------
  $coordinator_postgresql_tmpl	= "postgresqlxc/coordinator/postgresql.conf.erb"
  $coordinator_postgresql_params = {
    'listen_addresses'		 => "$ipaddress",
    'port'			 => 5432,
    'max_connections'		 => 100,
    'max_prepared_transactions'	 => 10,
    'max_pool_size'		 => 100,
    'min_pool_size'		 => 1,
    'shared_buffers'		 => '32MB',
    'log_destination'		 => 'stderr',
    'logging_collector'	         => 'on',
    'log_filename'		 =>  'pgxc-%a.log',
    'log_truncate_on_rotation'   =>  'on',
    'log_rotation_age'		 =>  '1d',
    'log_rotation_size'		 =>  0,
    'log_timezone'		 =>  'Australia/Victoria',
    'datestyle'			 =>  'iso, mdy',
    'timezone'			 =>  'Australia/Victoria',
    'lc_messages'		 =>  'en_US.UTF-8',
    'lc_monetary'		 =>  'en_US.UTF-8',
    'lc_numeric'		 =>  'en_US.UTF-8',
    'lc_time'			 =>  'en_US.UTF-8',
    'default_text_search_config' =>  'pg_catalog.english',
    'gtm_host'			 =>  'localhost',
    'gtm_port'                   =>  6666
  }
  $coordinator_pg_hba_tmpl      = "postgresqlxc/coordinator/pg_hba.conf.erb"
  $coordinator_pg_hba_params    = [
    ['local', 'all', 'all', ' ',                    'trust'],
    ['host',  'all', 'all', '127.0.0.1/32',         'trust'],
    ['host',  'all', 'all', '::1/128',              'trust']
  ]
  $coordinator_init_tmpl        = "postgresqlxc/coordinator/init.erb"
  $coordinator_init_params      = {}

  # ---------------------------------------------------------------------------
  # Datanode	
  # ---------------------------------------------------------------------------
  $datanode_postgresql_tmpl	= "postgresqlxc/datanode/postgresql.conf.erb"
  $datanode_postgresql_params = {
    'listen_addresses'		 => "$ipaddress",
    'port'			 => 15432,
    'max_connections'		 => 100,
    'max_prepared_transactions'	 => 10,
    'max_pool_size'		 => 100,
    'min_pool_size'		 => 1,
    'shared_buffers'		 => '32MB',
    'log_destination'		 => 'stderr',
    'logging_collector'	         => 'on',
    'log_filename'		 =>  'pgxc-%a.log',
    'log_truncate_on_rotation'   =>  'on',
    'log_rotation_age'		 =>  '1d',
    'log_rotation_size'		 =>  0,
    'log_timezone'		 =>  'Australia/Victoria',
    'datestyle'			 =>  'iso, mdy',
    'timezone'			 =>  'Australia/Victoria',
    'lc_messages'		 =>  'en_US.UTF-8',
    'lc_monetary'		 =>  'en_US.UTF-8',
    'lc_numeric'		 =>  'en_US.UTF-8',
    'lc_time'			 =>  'en_US.UTF-8',
    'default_text_search_config' =>  'pg_catalog.english',
    'gtm_host'			 =>  'localhost',
    'gtm_port'                   =>  6666
  }
  $datanode_pg_hba_tmpl      = "postgresqlxc/datanode/pg_hba.conf.erb"
  $datanode_pg_hba_params    = [
    ['local', 'all', 'all', ' ',                    'trust'],
    ['host',  'all', 'all', '127.0.0.1/32',         'trust'],
    ['host',  'all', 'all', '::1/128',              'trust']
  ]
  $datanode_init_tmpl        = "postgresqlxc/datanode/init.erb"
  $datanode_init_params      = {
  }

  $gtm_conf_tmpl	     = "postgresqlxc/gtm/gtm.conf.erb"
  $gtm_conf_params	     = {
    'listen_addresses'		 => $ipaddress,
    'port'			 => '6668',
    'startup'			 => 'ACT',
    'keepalives_idle'		 => 0,
    'keepalives_interval'	 => 0,
    'keepalives_count'		 => 0,
    'log_file'		         => 'gtm.log',
    'log_min_messages'           => 'WARNING',
    'synchronous_backup'         => 'off'
  }
  $gtm_init_tmpl        = "postgresqlxc/gtm/init.erb"
  $gtm_init_params      = {}

  $gtm_proxy_conf_tmpl	         = "postgresqlxc/gtm/gtm.conf.erb"
  $gtm_proxy_conf_params	 = {
    'listen_addresses'		 => $ipaddress,
    'port'			 => 6666,
    'worker_threads'		 => 1,
    'gtm_port'			 => 6668,
    'gtm_host'			 => $ipaddress,
    'gtm_connect_retry_interval' => 0,
    'keepalives_idle'		 => 0,
    'keepalives_interval'	 => 0,
    'keepalives_count'		 => 0,
    'log_file'		         => 'gtm_proxy.log',
    'log_min_messages'           => 'WARNING',
  }
  $gtm_proxy_init_tmpl           = "postgresqlxc/gtm/init.erb"
  $gtm_proxy_init_params         = {}

}
